pub struct NaryPatternBatchLayout {
pub head_arity: Vec<u32>,
pub join_count: Vec<u32>,
pub body_offset: Vec<u32>,
pub body_len: Vec<u32>,
pub atom_candidate_slot: Vec<u32>,
pub atom_arity: Vec<u32>,
pub atom_binding_offset: Vec<u32>,
pub binding_codes: Vec<u32>,
}Expand description
One pattern batch as the parallel flat arrays the kernel consumes.
Per pattern p: head arity head_arity[p], join-variable count
join_count[p], and body atoms body_offset[p] .. body_offset[p] + body_len[p]. Per atom a (flat index): candidate relation slot
atom_candidate_slot[a], arity atom_arity[a], and binding codes
binding_codes[atom_binding_offset[a] .. + atom_arity[a]].
Fields
head_arity: Vec<u32>join_count: Vec<u32>body_offset: Vec<u32>body_len: Vec<u32>atom_candidate_slot: Vec<u32>atom_arity: Vec<u32>atom_binding_offset: Vec<u32>binding_codes: Vec<u32>Trait Implementations
Sourceimpl Clone for NaryPatternBatchLayout
impl Clone for NaryPatternBatchLayout
Sourcefn clone(&self) -> NaryPatternBatchLayout
fn clone(&self) -> NaryPatternBatchLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NaryPatternBatchLayout
impl Debug for NaryPatternBatchLayout
impl Eq for NaryPatternBatchLayout
Sourceimpl PartialEq for NaryPatternBatchLayout
impl PartialEq for NaryPatternBatchLayout
Sourcefn eq(&self, other: &NaryPatternBatchLayout) -> bool
fn eq(&self, other: &NaryPatternBatchLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NaryPatternBatchLayout