pub struct ReferenceCoverage {
pub positives_covered: u32,
pub negatives_covered: u32,
}Expand description
Coverage counts for one pattern over one example set pair.
Fields
positives_covered: u32negatives_covered: u32Trait Implementations
Sourceimpl Clone for ReferenceCoverage
impl Clone for ReferenceCoverage
Sourcefn clone(&self) -> ReferenceCoverage
fn clone(&self) -> ReferenceCoverage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReferenceCoverage
Sourceimpl Debug for ReferenceCoverage
impl Debug for ReferenceCoverage
impl Eq for ReferenceCoverage
Sourceimpl PartialEq for ReferenceCoverage
impl PartialEq for ReferenceCoverage
Sourcefn eq(&self, other: &ReferenceCoverage) -> bool
fn eq(&self, other: &ReferenceCoverage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReferenceCoverage