pub struct InductionAlternative {
pub rule_fragment: String,
pub support_count: u64,
pub falsification_count: u64,
}Expand description
Rejected candidate rule with support and falsification counts.
Fields
rule_fragment: StringCandidate source fragment.
support_count: u64Number of positive examples covered by the rejected alternative.
falsification_count: u64Number of falsifying examples covered by the rejected alternative.
Implementations